"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDownloadFileByAliasPlugins = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _s = _interopRequireDefault(require("aws-sdk/clients/s3"));
var _utils = require("../utils");
var _gateway = require("@webiny/handler-aws/gateway");
var _extractFileInformation = require("./extractFileInformation");
var _getS3Object = require("./getS3Object");
const DEFAULT_CACHE_MAX_AGE = 30758400; // 1 year
const PRESIGNED_URL_EXPIRATION = 900; // 15 minutes

const {
  region
} = (0, _utils.getEnvironment)();
const s3 = new _s.default({
  region
});
const createDownloadFileByAliasPlugins = ({
  documentClient
}) => {
  async function getFileByAlias(tenant, alias) {
    const {
      Items,
      Count
    } = await documentClient.query({
      TableName: String(process.env.DB_TABLE),
      IndexName: "GSI1",
      Limit: 1,
      KeyConditionExpression: "GSI1_PK = :GSI1_PK AND GSI1_SK = :GSI1_SK",
      ExpressionAttributeValues: {
        ":GSI1_PK": `T#${tenant}#FM#FILE_ALIASES`,
        ":GSI1_SK": `/${alias}`
      }
    }).promise();
    if (!Items || Count === 0) {
      return null;
    }
    return Items[0].data.key ?? null;
  }
  return [new _gateway.RoutePlugin(({
    onGet,
    context
  }) => {
    onGet("/*", async (request, reply) => {
      const fileInfo = (0, _extractFileInformation.extractFileInformation)(request);

      // TODO: `root` tenant is hardcoded for now, to satisfy the basic use case.
      // We need to find a way to send tenant via `x-tenant` header, when images are being requested from
      // the frontend (website, admin, etc.) by alias.
      const realFilename = await getFileByAlias("root", fileInfo.filename);
      if (!realFilename) {
        return reply.code(404).type("text/html").send("Not Found");
      }
      const {
        params,
        object
      } = await (0, _getS3Object.getS3Object)((0, _objectSpread2.default)((0, _objectSpread2.default)({}, fileInfo), {}, {
        filename: realFilename
      }), s3, context);
      if (object && (0, _getS3Object.isSmallObject)(object)) {
        console.log("This is a small file; responding with object body.");
        return reply.headers({
          "Content-Type": object.ContentType,
          "Cache-Control": `public, max-age=${DEFAULT_CACHE_MAX_AGE}`,
          "x-webiny-base64-encoded": true
        }).send(object.Body || "");
      }
      console.log("This is a large object; redirecting to a presigned URL.");
      const presignedUrl = s3.getSignedUrl("getObject", {
        Bucket: params.Bucket,
        Key: params.Key,
        Expires: PRESIGNED_URL_EXPIRATION
      });

      // Lambda can return max 6MB of content, so if our object's size is larger, we are sending
      // a 301 Redirect, redirecting the user to the public URL of the object in S3.
      return reply.code(301).headers({
        Location: presignedUrl,
        "Cache-Control": "public, max-age=" + PRESIGNED_URL_EXPIRATION
      }).send("");
    });
  })];
};
exports.createDownloadFileByAliasPlugins = createDownloadFileByAliasPlugins;

//# sourceMappingURL=byAlias.js.map